=======
History
=======


v0.5 (2020-10-29)
-----------------

* Homology mapping table and function (`homology_convert`) are added.
* tables is now a function.


v0.4 (2020-10-27)
-----------------

* Entrez and UNIPROT IDs are added.


v0.3 (2020-06-04)
-----------------

* Ensembl version updated to 100. NCBI transcript IDs, gene lengths and gene exon lengths are added.


v0.1 (2019-04-07)
------------------

* First release on PyPI.
